@@ -64,9 +64,22 @@ static std::string filterAuthorizationHeader(const std::string& line) {
   }
 
   std::string filtered(line);
-  for (size_t i = pos + 15 ; i < filtered.length(); i++) {
+  bool formatted = false;
+
+  if (getenv("DAVIX_FORMAT_BEARER_TOKEN") != NULL) {
+    std::string content = line.substr(pos + 15);
+
+    // Format into "<header>: Bearer abcdefg...tuvwxyz"
+    if ((content.find("Bearer ") == 0) && (content.size() > 100)) {
+      filtered = line.substr(0, pos + 15) + "Bearer " + content.substr(7, 7) + "..." + content.substr(content.size() - 7);
+      formatted = true;
+    }
+  }
+
+  for (size_t i = pos + 15 ; i < filtered.length() && !formatted; i++) {
     filtered[i] = 'x';
   }
+
   return filtered;
 }
 
@@ -199,9 +212,17 @@ StandaloneCurlRequest::~StandaloneCurlRequest() {
 // Get a specific response header
 //------------------------------------------------------------------------------
 bool StandaloneCurlRequest::getAnswerHeader(const std::string &header_name, std::string &value) const {
-  for(auto it = _response_headers.begin(); it != _response_headers.end(); it++) {
-    if(it->first == header_name) {
-      value = it->second;
+  auto transform_to_lower = [](const std::string& str) -> std::string {
+    std::string lower(str);
+    std::transform(lower.begin(), lower.end(), lower.begin(), ::tolower);
+    return lower;
+  };
+
+  auto header_lower = transform_to_lower(header_name);
+
+  for (const auto& it: _response_headers) {
+    if (header_lower == transform_to_lower(it.first)) {
+      value = it.second;
       return true;
     }
   }
@@ -218,7 +239,7 @@ size_t StandaloneCurlRequest::getAnswerHeaders(std::vector<std::pair<std::string
 }
 
 //------------------------------------------------------------------------------
-// Traslate curl code into status
+// Translate curl code into status
 //------------------------------------------------------------------------------
 static Status curlCodeToStatus(CURLcode code) {
   std::ostringstream ss;
